coherence.upnp.core.soap_proxy (module) — Cohen3 0.8.0 documentation

# coherence.upnp.core.soap_proxy (module)

## `SOAPProxy`

A Proxy for making remote SOAP calls.

class `SOAPProxy`(url, namespace=None, envelope_attrib=None, header=None, soapaction=None)

  Bases: `coherence.log.LogAble`

  The `SOAPProxy` is based upon `twisted.web.soap.Proxy` and extracted to remove the SOAPpy dependency.

  Initialize the `SOAPProxy` class by passing the URL of the remote SOAP server.

  `logCategory` = 'soap'
  `callRemote`(soapmethod, arguments)

    You can use the method `callRemote()` like

        proxy.callRemote('foobar', 1, 2)

    to call remote method ‘foobar’ with args 1 and 2.

    Also you can call the method `callRemote()` with named arguments

        proxy.callRemote('foobar', x=1)

    Note

    The named arguments feature it will be useful to pass some headers (if needed) to our soap calls.

  `_cbGotResult`(result)
  `decode_result`(element)